@@ -305,7 +305,8 @@ def write_eda_config_and_args(
     fullpath = os.path.join(dirpath, filename)
     data = {}
     for x in ['command_name', 'config', 'target', 'args', 'modified_args', 'defines',
-              'incdirs', 'files_v', 'files_sv', 'files_vhd']:
+              'incdirs', 'files_v', 'files_sv', 'files_vhd', 'files_cpp', 'files_sdc',
+              'files_non_source']:
         # Use deep copy b/c otherwise these are references to opencos.eda.
         data[x] = copy.deepcopy(getattr(command_obj_ref, x, ''))
 
