@@ -387,6 +387,13 @@ class ExportHelper:
         paths.
         '''
 
+        # We'll copy files_sv and files_v later, along with discovered included files,
+        # need to copy any others:
+        remaing_files_to_cp = []
+        for x in self.cmd_design_obj.files.keys():
+            if x not in self.cmd_design_obj.files_v + self.cmd_design_obj.files_sv:
+                remaing_files_to_cp.append(x)
+
         # Also sets our list of included files.
         self.included_files = get_list_sv_included_files(
             all_src_files=self.cmd_design_obj.files_sv + self.cmd_design_obj.files_v,
@@ -398,7 +405,8 @@ class ExportHelper:
 
         info(f"export_helper: {self.target=} included files {self.included_files=}")
 
-        for filename in self.cmd_design_obj.files_non_source:
+
+        for filename in remaing_files_to_cp:
             dst = os.path.join(self.out_dir, os.path.split(filename)[1])
             if not os.path.exists(dst):
                 shutil.copy(src=filename, dst=dst)
@@ -415,11 +423,13 @@ class ExportHelper:
 
         info(f'export_helper: Creating DEPS.yml for {self.target=} in {self.out_dir=}')
 
-        # Need to strip path information from our files_sv and files_v:
+        # Need to strip path information from our files_sv and files_v
+        # (and all source files: cpp, sdc, etc; but skip the non-source files):
         deps_files = []
-        for fullpath in self.cmd_design_obj.files_sv + self.cmd_design_obj.files_v:
-            filename = os.path.split(fullpath)[1]
-            deps_files.append(filename)
+        for fullpath in self.cmd_design_obj.files.keys():
+            if fullpath not in self.cmd_design_obj.files_non_source:
+                filename = os.path.split(fullpath)[1]
+                deps_files.append(filename)
 
 
         data = {
