@@ -22,6 +22,9 @@ from opencos.eda_base import Tool
 from opencos.commands import CommandSim, CommandSynth, CommandProj, CommandBuild, \
     CommandFList, CommandUpload, CommandOpen
 
+from opencos.commands import sim
+
+
 class ToolVivado(Tool):
     '''ToolVivado used by opencos.eda for --tool=vivado'''
 
@@ -214,6 +217,12 @@ class CommandSimVivado(CommandSim, ToolVivado):
             command_list[0] += ".bat"
         command_list += self.tool_config.get('elab-args',
                                              '-s snapshot -timescale 1ns/1ps --stats').split()
+
+        # parameters
+        command_list.extend(
+            self.process_parameters_get_list(arg_prefix='-generic_top ')
+        )
+
         if self.tool_config.get('elab-waves-args', ''):
             command_list += self.tool_config.get('elab-waves-args', '').split()
         elif self.args['gui'] and self.args['waves']:
@@ -412,6 +421,9 @@ class CommandSynthVivado(CommandSynth, ToolVivado):
         defines = ""
         for key, value in self.defines.items():
             defines += (f"-verilog_define {key}" + (" " if value is None else f"={value} "))
+        parameters = ' '.join(
+            sim.parameters_dict_get_command_list(params=self.parameters, arg_prefix='-generic ')
+        )
         incdirs = ' '.join([f'-include_dirs {x}' for x in self.incdirs])
         flatten = ""
         if self.args['flatten-all']:
@@ -457,10 +469,10 @@ class CommandSynthVivado(CommandSynth, ToolVivado):
         tcl_lines += [
             "# FIRST PASS -- auto_detect_xpm",
             "synth_design -rtl -rtl_skip_ip -rtl_skip_constraints -no_timing_driven -no_iobuf " \
-            + f"-top {top} {incdirs} {defines} {v}",
+            + f"-top {top} {incdirs} {defines} {parameters} {v}",
             f"auto_detect_xpm {v} ",
             f"synth_design -no_iobuf -part {part} {flatten} -constrset constraints_1 " \
-            + f"-top {top} {incdirs} {defines} {v}",
+            + f"-top {top} {incdirs} {defines} {parameters} {v}",
             f"write_verilog -force {top}.vg {v}",
             f"report_utilization -file {top}.flat.util.rpt {v}",
             f"report_utilization -file {top}.hier.util.rpt {v} -hierarchical " \
@@ -753,6 +765,7 @@ class CommandFListVivado(CommandFList, ToolVivado):
         CommandFList.__init__(self, config=config)
         ToolVivado.__init__(self, config=self.config)
         self.args['all-sv'] = False
+        self.args['emit-parameter'] = False
 
 
 class CommandUploadVivado(CommandUpload, ToolVivado):
